@@ -177,12 +177,6 @@
         <source>Error</source>
         <translation>Error</translation>
     </message>
-    <message>
-        <source>Could not set up chroot environment.
-Please double-check the selected location.</source>
-        <translation type="vanished">No se pudo configurar el entorno chroot.
-Vuelva a comprobar la ubicación seleccionada.</translation>
-    </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="136"/>
         <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
@@ -264,10 +258,6 @@ Are you sure?</source>
         <source>Enter password to unlock %1 encrypted partition:</source>
         <translation>Introduzca la contraseña para desbloquear la partición cifrada %1:</translation>
     </message>
-    <message>
-        <source>Sorry, could not open %1 LUKS container</source>
-        <translation type="vanished">Lo sentimos, no se pudo abrir el contenedor %1 LUKS</translation>
-    </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="426"/>
         <source>Select GRUB location</source>
@@ -346,14 +336,6 @@ Are you sure?</source>
         <source>%1 Help</source>
         <translation>%1 Ayuda</translation>
     </message>
-    <message>
-        <source>Sorry, could not mount %1 partition</source>
-        <translation type="vanished">Lo sentimos, no se pudo montar la partición %1</translation>
-    </message>
-    <message>
-        <source>Could not create a temporary folder</source>
-        <translation type="vanished">No se pudo crear una carpeta temporal</translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -401,7 +383,7 @@ Are you sure?</source>
     <message>
         <location filename="../src/cli/controller.cpp" line="48"/>
         <source>Invalid selection. Enter a number </source>
-        <translation type="unfinished"></translation>
+        <translation>Selección no válida. Introduzca un número</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="157"/>
@@ -411,91 +393,91 @@ Are you sure?</source>
     <message>
         <location filename="../src/cli/controller.cpp" line="158"/>
         <source>1) Install GRUB</source>
-        <translation type="unfinished"></translation>
+        <translation>1) Instalar GRUB</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="159"/>
         <source>2) Repair GRUB (update-grub)</source>
-        <translation type="unfinished"></translation>
+        <translation>2) Reparar GRUB (update-grub)</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="160"/>
         <source>3) Regenerate initramfs</source>
-        <translation type="unfinished"></translation>
+        <translation>3) Regenerar initramfs</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="161"/>
         <source>4) Backup MBR/PBR</source>
-        <translation type="unfinished"></translation>
+        <translation>4) Respaldar MBR/PBR</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="162"/>
         <source>5) Restore MBR/PBR</source>
-        <translation type="unfinished"></translation>
+        <translation>5) Restaurar MBR/PBR</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="163"/>
         <source>q) Quit</source>
-        <translation type="unfinished"></translation>
+        <translation>q) Salir</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="164"/>
         <source>Select action [1-5 or &apos;q&apos; to quit]: </source>
-        <translation type="unfinished"></translation>
+        <translation>Seleccione una acción [1-5 o «q» para salir]:</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="170"/>
         <source>Invalid selection. Enter 1-5 or &apos;q&apos; to quit.</source>
-        <translation type="unfinished"></translation>
+        <translation>Selección no válida. Introduzca 1-5 o «q» para salir.</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="175"/>
         <source>Target: 0) MBR  1) ESP  2) Root</source>
-        <translation type="unfinished"></translation>
+        <translation>Objetivo: 0) MBR 1) ESP 2) Root</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="176"/>
         <source>Select target</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleccionar objetivo</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="182"/>
         <location filename="../src/cli/controller.cpp" line="217"/>
         <location filename="../src/cli/controller.cpp" line="230"/>
         <source>No partitions found. Returning to main menu.</source>
-        <translation type="unfinished"></translation>
+        <translation>No se han encontrado particiones. Volviendo al menú principal.</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="186"/>
         <location filename="../src/cli/controller.cpp" line="243"/>
         <location filename="../src/cli/controller.cpp" line="261"/>
         <source>No disks found. Returning to main menu.</source>
-        <translation type="unfinished"></translation>
+        <translation>No se han encontrado discos. Volviendo al menú principal.</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="191"/>
         <source>Select disk for MBR (e.g., sda)</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleccionar disco para MBR (p.ej. sda)</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="195"/>
         <source>Select partition for GRUB (e.g., sda1)</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleccionar partición para GRUB (p.ej. sda1)</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="200"/>
         <source>Select root partition of installed system</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleccionar la partición raíz del sistema instalado</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="218"/>
         <source>Select root partition to repair</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleccionar la partición raíz para reparar.</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="231"/>
         <source>Select root partition to regenerate initramfs</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleccionar la partición raíz para regenerar initramfs</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="244"/>
@@ -520,7 +502,7 @@ Are you sure?</source>
     <message>
         <location filename="../src/cli/controller.cpp" line="272"/>
         <source>WARNING: This will overwrite the first 446 bytes of /dev/</source>
-        <translation type="unfinished"></translation>
+        <translation>ADVERTENCIA: Esto sobrescribirá los primeros 446 bytes de /dev/</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="272"/>
@@ -531,13 +513,13 @@ Are you sure?</source>
         <location filename="../src/cli/controller.cpp" line="275"/>
         <source>yes</source>
         <comment>confirmation input: full word</comment>
-        <translation type="unfinished"></translation>
+        <translation>sí</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="276"/>
         <source>y</source>
         <comment>confirmation input: single-letter yes</comment>
-        <translation type="unfinished"></translation>
+        <translation>s</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="280"/>
@@ -547,7 +529,7 @@ Are you sure?</source>
     <message>
         <location filename="../src/cli/controller.cpp" line="287"/>
         <source>Unknown selection</source>
-        <translation type="unfinished"></translation>
+        <translation>Selección desconocida</translation>
     </message>
 </context>
 </TS>
