@@ -177,12 +177,6 @@
         <source>Error</source>
         <translation>Erreur</translation>
     </message>
-    <message>
-        <source>Could not set up chroot environment.
-Please double-check the selected location.</source>
-        <translation type="vanished">Impossible d’établir l’environnement chroot.
-Veuillez revérifier l’emplacement sélectionné.</translation>
-    </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="136"/>
         <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
@@ -264,10 +258,6 @@ Etes-vous sûr ?</translation>
         <source>Enter password to unlock %1 encrypted partition:</source>
         <translation>Entrer le mot de passe pour déverrouiller la partition chiffrée %1 :</translation>
     </message>
-    <message>
-        <source>Sorry, could not open %1 LUKS container</source>
-        <translation type="vanished">Désolé, impossible d’ouvrir le conteneur %1 LUKS</translation>
-    </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="426"/>
         <source>Select GRUB location</source>
@@ -346,14 +336,6 @@ Etes-vous sûr ?</translation>
         <source>%1 Help</source>
         <translation>%1 Aide</translation>
     </message>
-    <message>
-        <source>Sorry, could not mount %1 partition</source>
-        <translation type="vanished">Désolé, impossible de monter la partition %1</translation>
-    </message>
-    <message>
-        <source>Could not create a temporary folder</source>
-        <translation type="vanished">Impossible de créer un dossier temporaire</translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -531,13 +513,13 @@ Etes-vous sûr ?</translation>
         <location filename="../src/cli/controller.cpp" line="275"/>
         <source>yes</source>
         <comment>confirmation input: full word</comment>
-        <translation type="unfinished"></translation>
+        <translation>oui</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="276"/>
         <source>y</source>
         <comment>confirmation input: single-letter yes</comment>
-        <translation type="unfinished"></translation>
+        <translation>o</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="280"/>
