@@ -177,12 +177,6 @@
         <source>Error</source>
         <translation>त्रुटि</translation>
     </message>
-    <message>
-        <source>Could not set up chroot environment.
-Please double-check the selected location.</source>
-        <translation type="vanished">Chroot वातावरण सेट करना विफल।
-कृपया चयनित स्थान पुनः जाँचें।</translation>
-    </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="136"/>
         <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
@@ -264,10 +258,6 @@ Are you sure?</source>
         <source>Enter password to unlock %1 encrypted partition:</source>
         <translation>%1 एन्क्रिप्टेड विभाजन अभिगम हेतु कूटशब्द दर्ज करें :</translation>
     </message>
-    <message>
-        <source>Sorry, could not open %1 LUKS container</source>
-        <translation type="vanished">क्षमा करें, %1 LUKS कंटेनर खोलना विफल</translation>
-    </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="426"/>
         <source>Select GRUB location</source>
@@ -346,14 +336,6 @@ Are you sure?</source>
         <source>%1 Help</source>
         <translation>%1 सहायता</translation>
     </message>
-    <message>
-        <source>Sorry, could not mount %1 partition</source>
-        <translation type="vanished">क्षमा करें, %1 विभाजन माउंट करना विफल</translation>
-    </message>
-    <message>
-        <source>Could not create a temporary folder</source>
-        <translation type="vanished">अस्थायी फोल्डर बनाना विफल</translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -531,13 +513,13 @@ Are you sure?</source>
         <location filename="../src/cli/controller.cpp" line="275"/>
         <source>yes</source>
         <comment>confirmation input: full word</comment>
-        <translation type="unfinished"></translation>
+        <translation>हाँ</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="276"/>
         <source>y</source>
         <comment>confirmation input: single-letter yes</comment>
-        <translation type="unfinished"></translation>
+        <translation>ह</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="280"/>
