@@ -36,7 +36,7 @@
     <message>
         <location filename="../src/gui/mainwindow.ui" line="87"/>
         <source>Regenerate initramfs images</source>
-        <translation type="unfinished"></translation>
+        <translation>Regenerer initramfs-bilder</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="101"/>
@@ -177,12 +177,6 @@
         <source>Error</source>
         <translation>Feil</translation>
     </message>
-    <message>
-        <source>Could not set up chroot environment.
-Please double-check the selected location.</source>
-        <translation type="vanished">Klarte ikke sette opp chroot-miljø.
-Dobbeltsjekk valgt plassering.</translation>
-    </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="136"/>
         <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
@@ -191,7 +185,7 @@ Dobbeltsjekk valgt plassering.</translation>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="170"/>
         <source>Generating initramfs images on: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Genererer initramfs-bilder på: %1</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="199"/>
@@ -264,10 +258,6 @@ Er du sikker?</translation>
         <source>Enter password to unlock %1 encrypted partition:</source>
         <translation>Angi passord for å låse opp den krypterte partisjonen %1:</translation>
     </message>
-    <message>
-        <source>Sorry, could not open %1 LUKS container</source>
-        <translation type="vanished">Klarte ikke åpne LUKS-partisjonen %1</translation>
-    </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="426"/>
         <source>Select GRUB location</source>
@@ -276,7 +266,7 @@ Er du sikker?</translation>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="435"/>
         <source>Select initramfs options</source>
-        <translation type="unfinished"></translation>
+        <translation>Velg initramfs-alternativer</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="445"/>
@@ -346,14 +336,6 @@ Er du sikker?</translation>
         <source>%1 Help</source>
         <translation>Hjelpetekst for %1</translation>
     </message>
-    <message>
-        <source>Sorry, could not mount %1 partition</source>
-        <translation type="vanished">Klarte ikke montere partisjonen %1</translation>
-    </message>
-    <message>
-        <source>Could not create a temporary folder</source>
-        <translation type="vanished">Klarte ikke å opprette midlertidig mappe</translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -396,158 +378,158 @@ Er du sikker?</translation>
     <message>
         <location filename="../src/cli/controller.cpp" line="29"/>
         <source>Invalid index. Try again: </source>
-        <translation type="unfinished"></translation>
+        <translation>Ugyldig indeks. Forsøk igjen:</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="48"/>
         <source>Invalid selection. Enter a number </source>
-        <translation type="unfinished"></translation>
+        <translation>Ugyldig valg. Skriv et tall</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="157"/>
         <source>MX Boot Repair (CLI)</source>
-        <translation type="unfinished"></translation>
+        <translation>MX Oppstartsreparasjon (KLI)</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="158"/>
         <source>1) Install GRUB</source>
-        <translation type="unfinished"></translation>
+        <translation>1) Installer GRUB</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="159"/>
         <source>2) Repair GRUB (update-grub)</source>
-        <translation type="unfinished"></translation>
+        <translation>2) Reparer GRUB (update-grub)</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="160"/>
         <source>3) Regenerate initramfs</source>
-        <translation type="unfinished"></translation>
+        <translation>3) Regenerer initramfs</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="161"/>
         <source>4) Backup MBR/PBR</source>
-        <translation type="unfinished"></translation>
+        <translation>4) Reservekopier MBR/PBR</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="162"/>
         <source>5) Restore MBR/PBR</source>
-        <translation type="unfinished"></translation>
+        <translation>5) Gjenopprett MBR/PBR</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="163"/>
         <source>q) Quit</source>
-        <translation type="unfinished"></translation>
+        <translation>q) Avslutt</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="164"/>
         <source>Select action [1-5 or &apos;q&apos; to quit]: </source>
-        <translation type="unfinished"></translation>
+        <translation>Velg handling [1-5 eller &apos;q&apos; for å avslutte]:</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="170"/>
         <source>Invalid selection. Enter 1-5 or &apos;q&apos; to quit.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ugyldig valg. Velg 1-5 eller &apos;q&apos; for å avslutte.</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="175"/>
         <source>Target: 0) MBR  1) ESP  2) Root</source>
-        <translation type="unfinished"></translation>
+        <translation>Mål 0) MBR  1) ESP  2) Rot</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="176"/>
         <source>Select target</source>
-        <translation type="unfinished"></translation>
+        <translation>Velg mål</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="182"/>
         <location filename="../src/cli/controller.cpp" line="217"/>
         <location filename="../src/cli/controller.cpp" line="230"/>
         <source>No partitions found. Returning to main menu.</source>
-        <translation type="unfinished"></translation>
+        <translation>Fant ingen partisjoner. Går tilbake til hovedmenyen.</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="186"/>
         <location filename="../src/cli/controller.cpp" line="243"/>
         <location filename="../src/cli/controller.cpp" line="261"/>
         <source>No disks found. Returning to main menu.</source>
-        <translation type="unfinished"></translation>
+        <translation>Fant ingen disker. Går tilbake til hovedmenyen.</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="191"/>
         <source>Select disk for MBR (e.g., sda)</source>
-        <translation type="unfinished"></translation>
+        <translation>Velg disk for MBR (f.eks. sda)</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="195"/>
         <source>Select partition for GRUB (e.g., sda1)</source>
-        <translation type="unfinished"></translation>
+        <translation>Velg partisjon for GRUB (f.eks. sda1)</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="200"/>
         <source>Select root partition of installed system</source>
-        <translation type="unfinished"></translation>
+        <translation>Velg rotpartisjon for det installerte systemet</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="218"/>
         <source>Select root partition to repair</source>
-        <translation type="unfinished"></translation>
+        <translation>Velg rotpartisjon som skal repareres</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="231"/>
         <source>Select root partition to regenerate initramfs</source>
-        <translation type="unfinished"></translation>
+        <translation>Velg rotpartisjon for å regenerere initramfs</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="244"/>
         <source>Select disk to back up MBR/PBR from</source>
-        <translation type="unfinished"></translation>
+        <translation>Velg disk som MBR/PBR skal reservekopieres fra</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="247"/>
         <source>Output file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
-        <translation type="unfinished"></translation>
+        <translation>Sti til utdatafil (eller &apos;b&apos; for å gå tilbake, &apos;q&apos; for å avslutte):</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="262"/>
         <source>Select disk to restore MBR/PBR to</source>
-        <translation type="unfinished"></translation>
+        <translation>Velg disk som MBR/PBR skal gjenopprettes til</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="265"/>
         <source>Input backup file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
-        <translation type="unfinished"></translation>
+        <translation>Sti til inndatafil (eller &apos;b&apos; for å gå tilbake, &apos;q&apos; for å avslutte):</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="272"/>
         <source>WARNING: This will overwrite the first 446 bytes of /dev/</source>
-        <translation type="unfinished"></translation>
+        <translation>ADVARSEL: Dette vil overskrive de første 446 byte av /dev/</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="272"/>
         <source>. Continue? [y/N]: </source>
-        <translation type="unfinished"></translation>
+        <translation>. Fortsett? [y/N]:</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="275"/>
         <source>yes</source>
         <comment>confirmation input: full word</comment>
-        <translation type="unfinished"></translation>
+        <translation>ja</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="276"/>
         <source>y</source>
         <comment>confirmation input: single-letter yes</comment>
-        <translation type="unfinished"></translation>
+        <translation>j</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="280"/>
         <source>Cancelled.</source>
-        <translation type="unfinished"></translation>
+        <translation>Avbrutt.</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="287"/>
         <source>Unknown selection</source>
-        <translation type="unfinished"></translation>
+        <translation>Ukjent valg</translation>
     </message>
 </context>
 </TS>
