@@ -177,12 +177,6 @@
         <source>Error</source>
         <translation>Foutmelding</translation>
     </message>
-    <message>
-        <source>Could not set up chroot environment.
-Please double-check the selected location.</source>
-        <translation type="vanished">Kan de chroot omgeving niet opzetten.
-Controleer alstublieft de geselecteerde locatie.</translation>
-    </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="136"/>
         <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
@@ -264,10 +258,6 @@ Weet u het zeker?</translation>
         <source>Enter password to unlock %1 encrypted partition:</source>
         <translation>Voer wachtwoord in om versleutelde partitie %1 te ontgrendelen:</translation>
     </message>
-    <message>
-        <source>Sorry, could not open %1 LUKS container</source>
-        <translation type="vanished">Sorry, kon %1 LUKS container niet openen</translation>
-    </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="426"/>
         <source>Select GRUB location</source>
@@ -346,14 +336,6 @@ Weet u het zeker?</translation>
         <source>%1 Help</source>
         <translation>%1 Help</translation>
     </message>
-    <message>
-        <source>Sorry, could not mount %1 partition</source>
-        <translation type="vanished">Sorry, kon partitie %1 niet aankoppelen</translation>
-    </message>
-    <message>
-        <source>Could not create a temporary folder</source>
-        <translation type="vanished">Kon tijdelijke folder niet creëren</translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -537,7 +519,7 @@ Weet u het zeker?</translation>
         <location filename="../src/cli/controller.cpp" line="276"/>
         <source>y</source>
         <comment>confirmation input: single-letter yes</comment>
-        <translation type="unfinished"></translation>
+        <translation>j</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="280"/>
