@@ -11,12 +11,12 @@
     <message>
         <location filename="../src/gui/mainwindow.ui" line="45"/>
         <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
-        <translation>O Reparador de Inicialização do MX (MX Boot Repair) é um utilitário que pode ser utilizado para reinstalar ou reparar o gerenciador/carregador de inicialização GRUB na ESP (EFI System Partition), no MBR (Master Boot Record) ou na partição raiz ( /, root). O reparador fornece as opções de reconstruir o arquivo de configurações do GRUB, fazer cópia de segurança e restaurar o MBR ou o PBR (root).</translation>
+        <translation>O Reparador de Inicialização do MX (MX Boot Repair) é um utilitário que pode ser utilizado para reinstalar ou reparar o gerenciador/carregador de inicialização GRUB (GRand Unified Bootloader) na ESP (EFI System Partition), no MBR (Master Boot Record) ou na partição raiz ( /, root). O reparador fornece as opções de reconstruir o arquivo de configurações do GRUB, fazer cópia de segurança e restaurar o MBR ou o PBR (root).</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="64"/>
         <source>What would you like to do?</source>
-        <translation>O que você pretende fazer?</translation>
+        <translation>O que você quer fazer?</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="94"/>
@@ -36,12 +36,12 @@
     <message>
         <location filename="../src/gui/mainwindow.ui" line="87"/>
         <source>Regenerate initramfs images</source>
-        <translation>Regenerar as imagens do arquivos ‘initramfs’</translation>
+        <translation>Regenerar as imagens dos arquivos ‘initramfs’</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="101"/>
         <source>Restore MBR or PBR from backup (legacy boot only)</source>
-        <translation>Restaurar MBR ou PBR a partir de cópia (apenas em computadores com BIOS)</translation>
+        <translation>Restaurar o MBR ou o PBR a partir de cópia (apenas em computadores com o BIOS)</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="134"/>
@@ -69,7 +69,7 @@
         <location filename="../src/gui/mainwindow.ui" line="193"/>
         <location filename="../src/gui/mainwindow.cpp" line="420"/>
         <source>Location:</source>
-        <translation>Localização:</translation>
+        <translation>Local:</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="218"/>
@@ -96,7 +96,7 @@
         <location filename="../src/gui/mainwindow.ui" line="278"/>
         <location filename="../src/gui/mainwindow.cpp" line="427"/>
         <source>Select root location:</source>
-        <translation>Selecionar a localização da raiz ( /, root):</translation>
+        <translation>Selecionar o local da raiz ( /, root):</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="300"/>
@@ -107,7 +107,7 @@
     <message>
         <location filename="../src/gui/mainwindow.ui" line="389"/>
         <source>About this application</source>
-        <translation>Sobre este aplicativo</translation>
+        <translation>Sobre este programa</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="392"/>
@@ -163,7 +163,7 @@
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="98"/>
         <source>GRUB is being installed on %1 device.</source>
-        <translation>O GRUB está sendo instalado em %1</translation>
+        <translation>O GRUB está sendo instalado no dispositivo %1.</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="286"/>
@@ -175,13 +175,7 @@
         <location filename="../src/gui/mainwindow.cpp" line="485"/>
         <location filename="../src/gui/mainwindow.cpp" line="492"/>
         <source>Error</source>
-        <translation>Erro</translation>
-    </message>
-    <message>
-        <source>Could not set up chroot environment.
-Please double-check the selected location.</source>
-        <translation type="vanished">Não foi possível configurar o ambiente ‘Chroot’ Change root).
-Por favor, verifique novamente o local que foi selecionado.</translation>
+        <translation>Ocorreu um erro</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="136"/>
@@ -206,7 +200,7 @@ Por favor, verifique novamente o local que foi selecionado.</translation>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="256"/>
         <source>You are going to write the content of </source>
-        <translation>Você vai escrever o conteúdo de</translation>
+        <translation>Você vai gravar o conteúdo de</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="256"/>
@@ -225,17 +219,17 @@ Você tem certeza?</translation>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="263"/>
         <source>Restoring MBR/PBR from backup to %1 device.</source>
-        <translation>Restaurando MBR/PBR para o dispositivo %1 a partir da cópia de segurança.</translation>
+        <translation>Restaurando o MBR ou o PBR para o dispositivo %1 a partir da cópia de segurança.</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="287"/>
         <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
-        <translation>Não foi possível encontrar a partição ESP (EFI System Partition) em qualquer dos discos do sistema. Crie uma ESP e tente novamente.</translation>
+        <translation>Não foi possível encontrar uma partição ESP (EFI System Partition) em qualquer um dos discos que estão instalados no computador. Por favor, crie uma ESP e tente novamente.</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="299"/>
         <source>Select %1 location:</source>
-        <translation>Selecionar a localização de %1:</translation>
+        <translation>Selecionar o local de %1:</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="322"/>
@@ -245,7 +239,7 @@ Você tem certeza?</translation>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="338"/>
         <source>Success</source>
-        <translation>Sucesso</translation>
+        <translation>O processo ocorreu com sucesso</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="338"/>
@@ -255,23 +249,19 @@ Você tem certeza?</translation>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="344"/>
         <source>Process finished. Errors have occurred.</source>
-        <translation>O processo foi concluído. Ocorreram alguns erros.</translation>
+        <translation>O processo foi concluído. Contudo, ocorreram alguns erros.</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="105"/>
         <location filename="../src/gui/mainwindow.cpp" line="144"/>
         <location filename="../src/gui/mainwindow.cpp" line="176"/>
         <source>Enter password to unlock %1 encrypted partition:</source>
-        <translation>Inserir a senha para desbloquear a partição criptografada/encriptada %1:</translation>
-    </message>
-    <message>
-        <source>Sorry, could not open %1 LUKS container</source>
-        <translation type="vanished">Desculpe, não foi possível abrir o contêiner %1 LUKS</translation>
+        <translation>Insira a senha para desbloquear a partição que está criptografada/encriptada %1:</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="426"/>
         <source>Select GRUB location</source>
-        <translation>Selecione a localização do GRUB</translation>
+        <translation>Selecione o local do GRUB</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="435"/>
@@ -286,7 +276,7 @@ Você tem certeza?</translation>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="450"/>
         <source>Select Item to Restore</source>
-        <translation>Selecione o item para restaurar</translation>
+        <translation>Selecione o item para ser restaurado</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="460"/>
@@ -314,7 +304,7 @@ Você tem certeza?</translation>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="490"/>
         <source>Select MBR or PBR backup file</source>
-        <translation>Selecione o arquivo da cópia de segurança (backup) MBR ou PBR</translation>
+        <translation>Selecione o arquivo da cópia de segurança (backup) do MBR ou do PBR</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="508"/>
@@ -329,7 +319,7 @@ Você tem certeza?</translation>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="511"/>
         <source>Simple boot repair program for MX Linux</source>
-        <translation>Programa simples de reparo de inicialização (boot) para o MX Linux.</translation>
+        <translation>Programa para reparar a inicialização (boot) para o MX Linux.</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="513"/>
@@ -346,14 +336,6 @@ Você tem certeza?</translation>
         <source>%1 Help</source>
         <translation>Ajuda do %1</translation>
     </message>
-    <message>
-        <source>Sorry, could not mount %1 partition</source>
-        <translation type="vanished">Desculpe, não foi possível montar a partição %1</translation>
-    </message>
-    <message>
-        <source>Could not create a temporary folder</source>
-        <translation type="vanished">Não foi possível criar uma pasta temporária</translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -366,7 +348,7 @@ Você tem certeza?</translation>
         <location filename="../src/gui/about.cpp" line="53"/>
         <location filename="../src/gui/about.cpp" line="63"/>
         <source>Changelog</source>
-        <translation>Relatório de alterações</translation>
+        <translation>Relatório de Alterações</translation>
     </message>
     <message>
         <location filename="../src/gui/about.cpp" line="54"/>
@@ -386,7 +368,7 @@ Você tem certeza?</translation>
     <message>
         <location filename="../src/gui/main.cpp" line="82"/>
         <source>Error</source>
-        <translation>Ocorreu um Erro</translation>
+        <translation>Ocorreu um erro</translation>
     </message>
     <message>
         <location filename="../src/gui/main.cpp" line="83"/>
@@ -396,158 +378,158 @@ Você tem certeza?</translation>
     <message>
         <location filename="../src/cli/controller.cpp" line="29"/>
         <source>Invalid index. Try again: </source>
-        <translation type="unfinished"></translation>
+        <translation>O índice não é válido. Por favor, tente novamente: </translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="48"/>
         <source>Invalid selection. Enter a number </source>
-        <translation type="unfinished"></translation>
+        <translation>A seleção não é válida. Por favor, insira um número</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="157"/>
         <source>MX Boot Repair (CLI)</source>
-        <translation type="unfinished"></translation>
+        <translation>Reparador de Inicialização do MX por Interface de Linha de Comandos</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="158"/>
         <source>1) Install GRUB</source>
-        <translation type="unfinished"></translation>
+        <translation>1) Instalar o GRUB</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="159"/>
         <source>2) Repair GRUB (update-grub)</source>
-        <translation type="unfinished"></translation>
+        <translation>2) Reparar o GRUB e aplicar o comando ‘update-grub’</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="160"/>
         <source>3) Regenerate initramfs</source>
-        <translation type="unfinished"></translation>
+        <translation>3) Regenerar o ‘initramfs’</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="161"/>
         <source>4) Backup MBR/PBR</source>
-        <translation type="unfinished"></translation>
+        <translation>4) Fazer a cópia de segurança do MBR/PBR</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="162"/>
         <source>5) Restore MBR/PBR</source>
-        <translation type="unfinished"></translation>
+        <translation>5) Restaurar o MBR ou o PBR</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="163"/>
         <source>q) Quit</source>
-        <translation type="unfinished"></translation>
+        <translation>q) Desistir</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="164"/>
         <source>Select action [1-5 or &apos;q&apos; to quit]: </source>
-        <translation type="unfinished"></translation>
+        <translation>Selecione a ação com as teclas ‘1’ a ‘5’ ou ‘q’ para sair: </translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="170"/>
         <source>Invalid selection. Enter 1-5 or &apos;q&apos; to quit.</source>
-        <translation type="unfinished"></translation>
+        <translation>A seleção não é válida. Pressione as teclas ‘1’ a ‘5’ ou ‘q’ para sair.</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="175"/>
         <source>Target: 0) MBR  1) ESP  2) Root</source>
-        <translation type="unfinished"></translation>
+        <translation>O objetivo é: 0) Para o MBR, 1) Para o ESP ou 2) Para  o Root (Raiz ou /)</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="176"/>
         <source>Select target</source>
-        <translation type="unfinished"></translation>
+        <translation>Selecione o objetivo</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="182"/>
         <location filename="../src/cli/controller.cpp" line="217"/>
         <location filename="../src/cli/controller.cpp" line="230"/>
         <source>No partitions found. Returning to main menu.</source>
-        <translation type="unfinished"></translation>
+        <translation>Nenhuma partição foi encontrada. Retornando para o menu principal.</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="186"/>
         <location filename="../src/cli/controller.cpp" line="243"/>
         <location filename="../src/cli/controller.cpp" line="261"/>
         <source>No disks found. Returning to main menu.</source>
-        <translation type="unfinished"></translation>
+        <translation>Nenhum disco (IDE, Sata, SSD, etc.) foi encontrado. Retornando para o menu principal.</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="191"/>
         <source>Select disk for MBR (e.g., sda)</source>
-        <translation type="unfinished"></translation>
+        <translation>Selecione o disco (IDE, Sata, SSD, etc.) para o MBR. Por exemplo, ‘sda’ ou ‘sdb’ ou ‘sdc’, etc.</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="195"/>
         <source>Select partition for GRUB (e.g., sda1)</source>
-        <translation type="unfinished"></translation>
+        <translation>Selecione a partição para o GRUB. Por exemplo, ‘sda1’ ou ‘sda2’ ou ‘sdb1’ ou ‘sdb2’, etc.</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="200"/>
         <source>Select root partition of installed system</source>
-        <translation type="unfinished"></translation>
+        <translation>Selecione a partição de ‘root’ (raiz ou /) do sistema operacional que está instalado</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="218"/>
         <source>Select root partition to repair</source>
-        <translation type="unfinished"></translation>
+        <translation>Selecione a partição de ‘root’ (raiz ou /) para ser reparada</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="231"/>
         <source>Select root partition to regenerate initramfs</source>
-        <translation type="unfinished"></translation>
+        <translation>Selecione a partição de ‘root’ para regenerar o ‘initramfs’</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="244"/>
         <source>Select disk to back up MBR/PBR from</source>
-        <translation type="unfinished"></translation>
+        <translation>Selecione o disco (IDE, Sata, SSD, etc.) para fazer a cópia de segurança do MBR ou do PBR</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="247"/>
         <source>Output file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
-        <translation type="unfinished"></translation>
+        <translation>Informe o caminho do arquivo de saída ou pressione a tecla ‘b’ para voltar ou ‘q’ para sair: </translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="262"/>
         <source>Select disk to restore MBR/PBR to</source>
-        <translation type="unfinished"></translation>
+        <translation>Selecione o disco (IDE, Sata, SSD, etc.) para restaurar o MBR ou o PBR</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="265"/>
         <source>Input backup file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
-        <translation type="unfinished"></translation>
+        <translation>Informe o caminho do arquivo de entrada ou pressione a tecla ‘b’ para voltar ou ‘q’ para sair: </translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="272"/>
         <source>WARNING: This will overwrite the first 446 bytes of /dev/</source>
-        <translation type="unfinished"></translation>
+        <translation>AVISO: Esta ação irá substituir os primeiros 446 bytes do /dev/</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="272"/>
         <source>. Continue? [y/N]: </source>
-        <translation type="unfinished"></translation>
+        <translation>. Você quer continuar? [s/N]: </translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="275"/>
         <source>yes</source>
         <comment>confirmation input: full word</comment>
-        <translation type="unfinished"></translation>
+        <translation>sim</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="276"/>
         <source>y</source>
         <comment>confirmation input: single-letter yes</comment>
-        <translation type="unfinished"></translation>
+        <translation>s</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="280"/>
         <source>Cancelled.</source>
-        <translation type="unfinished"></translation>
+        <translation>Foi cancelado.</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="287"/>
         <source>Unknown selection</source>
-        <translation type="unfinished"></translation>
+        <translation>A seleção não é conhecida</translation>
     </message>
 </context>
 </TS>
