@@ -177,12 +177,6 @@
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
-    <message>
-        <source>Could not set up chroot environment.
-Please double-check the selected location.</source>
-        <translation type="vanished">Не удалось установить среду chroot.
-Пожалуйста, перепроверьте выбранное местоположение.</translation>
-    </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="136"/>
         <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
@@ -264,10 +258,6 @@ Are you sure?</source>
         <source>Enter password to unlock %1 encrypted partition:</source>
         <translation>Введите пароль для открытия зашифрованного раздела %1:</translation>
     </message>
-    <message>
-        <source>Sorry, could not open %1 LUKS container</source>
-        <translation type="vanished">Извините, не получилось открыть контейнер LUKS %1</translation>
-    </message>
     <message>
         <location filename="../src/gui/mainwindow.cpp" line="426"/>
         <source>Select GRUB location</source>
@@ -346,14 +336,6 @@ Are you sure?</source>
         <source>%1 Help</source>
         <translation>%1 Справка</translation>
     </message>
-    <message>
-        <source>Sorry, could not mount %1 partition</source>
-        <translation type="vanished">Простите, не удалось примонтировать раздел %1</translation>
-    </message>
-    <message>
-        <source>Could not create a temporary folder</source>
-        <translation type="vanished">Не удалось создать временную папку</translation>
-    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -531,13 +513,13 @@ Are you sure?</source>
         <location filename="../src/cli/controller.cpp" line="275"/>
         <source>yes</source>
         <comment>confirmation input: full word</comment>
-        <translation type="unfinished"></translation>
+        <translation>да</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="276"/>
         <source>y</source>
         <comment>confirmation input: single-letter yes</comment>
-        <translation type="unfinished"></translation>
+        <translation>y</translation>
     </message>
     <message>
         <location filename="../src/cli/controller.cpp" line="280"/>
